==> bibledit-web-1.4.zip: bibledit-web/help/scripts/index.php <==
<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<h1><?php echo gettext ("Help") ?></h1>
<p><a href="introduction.php"><?php echo gettext ("Introduction") ?></a></p>
<p><a href="installation.php"><?php echo gettext ("Installation") ?></a></p>
<p><a href="methodology.php"><?php echo gettext ("Methodology") ?></a></p>
<p><a href="navigation.php"><?php echo gettext ("Navigation") ?></a></p>
<p><a href="shortcuts.php"><?php echo gettext ("Keyboard shortcuts") ?></a></p>
<p><a href="consultations.php"><?php echo gettext ("Consultations") ?></a></p>
<p><a href="consistency.php"><?php echo gettext ("Consistency") ?></a></p>
<p><a href="typesetting.php"><?php echo gettext ("Typesetting") ?></a></p>
<p><a href="tipstricks.php"><?php echo gettext ("Tips and tricks") ?></a></p>
<p><a href="about.php"><?php echo gettext ("About") ?></a></p>

==> bibledit-web-1.5.zip: bibledit-web/help/scripts/index.php <==
<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<h1><?php echo gettext ("Help") ?></h1>
<p><a href="introduction.php"><?php echo gettext ("Introduction") ?></a></p>
<p><a href="installation.php"><?php echo gettext ("Installation") ?></a></p>
<p><a href="methodology.php"><?php echo gettext ("Methodology") ?></a></p>
<p><a href="navigation.php"><?php echo gettext ("Navigation") ?></a></p>
<p><a href="shortcuts.php"><?php echo gettext ("Keyboard shortcuts") ?></a></p>
<p><a href="consultations.php"><?php echo gettext ("Consultations") ?></a></p>
<p><a href="consistency.php"><?php echo gettext ("Consistency") ?></a></p>
<p><a href="checks.php"><?php echo gettext ("Checks") ?></a></p>
<p><a href="teams.php"><?php echo gettext ("Teams") ?></a></p>
<p><a href="typesetting.php"><?php echo gettext ("Typesetting") ?></a></p>
<p><a href="tipstricks.php"><?php echo gettext ("Tips and tricks") ?></a></p>
<p><a href="about.php"><?php echo gettext ("About") ?></a></p>
